@@ -1,11 +1,11 @@
 def not_(a):
-  """Checks if value is false. `📘`_
+  """Checks if value is False. `📘`_
 
   - a: a boolean
 
   Example:
-    >>> not(False) == True
-    >>> not(True)  == False
+    >>> not_(False) == True
+    >>> not_(True)  == False
 
   .. _📘:
     https://github.com/python3f/extra-boolean/wiki/not
